@@ -961,7 +961,7 @@ END
        "            },%NL%".
        "            store => {%NL%".
        "               class         => %SQ%DBIx::Class%SQ%,%NL%".
-       "               user_model    => %SQ%DB::User%SQ%,%NL%".
+       "               user_model    => %SQ%DB::Users%SQ%,%NL%".
        "               role_relation => %SQ%roles%SQ%,%NL%".
        "               role_field    => %SQ%name%SQ%,%NL%".
        "            }%NL%".
@@ -1018,6 +1018,14 @@ ENDD
       "echo -e \"$content\" > root/src/login/login.tt2");
    ($stdout,$stderr)=$handle->cmd("mkdir -v db lib/FullAutoAPI/Schema",
       '__display__');
+   ($stdout,$stderr)=$handle->cwd('db');
+   ($stdout,$stderr)=$handle->cmd(
+      "wget --random-wait --progress=dot ".
+      "http://dev.catalyst.perl.org/repos/Catalyst/trunk/".
+      "examples/RestYUI/db/adventrest.db",
+      '__display__');
+   ($stdout,$stderr)=$handle->cmd("mv adventrest.db fullautoapi.db");
+   ($stdout,$stderr)=$handle->cwd('..');
    my $db_sql="db.sql";
    $content=<<'END';
 DROP TABLE IF EXISTS users;
@@ -1056,63 +1064,24 @@ INSERT INTO user_roles (user_id, role_id) VALUES (
     (SELECT id FROM users WHERE username = 'admin'),
     (SELECT id FROM roles WHERE name     = 'admin')
 );
-CREATE TABLE user (
- user_id TYPE text NOT NULL PRIMARY KEY,
- fullname TYPE text NOT NULL,
- description TYPE text NOT NULL
-); 
 END
+#CREATE TABLE user (
+# user_id TYPE text NOT NULL PRIMARY KEY,
+# fullname TYPE text NOT NULL,
+# description TYPE text NOT NULL
+#); 
+#END
    ($stdout,$stderr)=$handle->cmd("touch $db_sql");
    ($stdout,$stderr)=$handle->cmd("chmod -v 777 $db_sql",'__display__');
    ($stdout,$stderr)=$handle->cmd("echo \"$content\" > $db_sql");
    ($stdout,$stderr)=$handle->cmd("chmod -v 644 $db_sql",'__display__');
-   #($stdout,$stderr)=$handle->cmd('sqlite3 db/fullautoapi.db < db.sql');
-   ($stdout,$stderr)=$handle->cwd('db');
-   ($stdout,$stderr)=$handle->cmd(
-      "wget --random-wait --progress=dot ".
-      "http://dev.catalyst.perl.org/repos/Catalyst/trunk/".
-      "examples/RestYUI/db/adventrest.db",
-      '__display__');
-   ($stdout,$stderr)=$handle->cmd("mv adventrest.db fullautoapi.db");
-   ($stdout,$stderr)=$handle->cwd("../lib/FullAutoAPI");
-   $content=<<'END';
-#
-# FullAutoAPI::Schema.pm
-#
- 
-package FullAutoAPI::Schema;
-use base qw/DBIx::Class::Schema/;
- 
-__PACKAGE__->load_classes(qw/User/);
- 
-1;
-END
-   ($stdout,$stderr)=$handle->cmd("touch Schema.pm");
-   ($stdout,$stderr)=$handle->cmd("chmod -v 777 Schema.pm",'__display__');
-   ($stdout,$stderr)=$handle->cmd("echo \"$content\" > Schema.pm");
-   ($stdout,$stderr)=$handle->cmd("chmod -v 644 Schema.pm",'__display__');
-   $content=<<'END';
-package FullAutoAPI::Schema::User;
- 
-use base qw/DBIx::Class/;
-__PACKAGE__->load_components(qw/Core/);
-__PACKAGE__->table('user');
-__PACKAGE__->add_columns(qw/user_id fullname description/);
-__PACKAGE__->set_primary_key('user_id');
- 
-1;
-END
-   ($stdout,$stderr)=$handle->cwd("Schema");
-   ($stdout,$stderr)=$handle->cmd("touch User.pm");
-   ($stdout,$stderr)=$handle->cmd("chmod -v 777 User.pm",'__display__');
-   ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > User.pm");
-   ($stdout,$stderr)=$handle->cmd("chmod -v 644 User.pm",'__display__');
-   ($stdout,$stderr)=$handle->cwd("../../..");
+   ($stdout,$stderr)=$handle->cmd('sqlite3 db/fullautoapi.db < db.sql');
    ($stdout,$stderr)=$handle->cmd("./script/fullautoapi_create.pl ".
       "model DB DBIC::Schema FullAutoAPI::Schema create=static ".
-      "components=TimeStamp,PassphraseColumn dbi:SQLite:db/fullautoapi.db",
+      "components=TimeStamp,PassphraseColumn ".
+      "moniker_map='{ users => "Users" }' dbi:SQLite:db/fullautoapi.db",
       '__display__');
-   my $user_path="./lib/FullAutoAPI/Schema/Result/User.pm";
+   my $user_path="./lib/FullAutoAPI/Schema/Result/Users.pm";
    $ad="%NL%__PACKAGE__->add_columns(%NL%".
        "    %SQ%+password%SQ% => {%NL%".
        "        passphrase       => %SQ%rfc2307%SQ%,%NL%".
@@ -1233,7 +1202,7 @@ BEGIN { \\x24ENV{CATALYST_DEBUG} = 0 }
 use FullAutoAPI;
 use DateTime;
  
-my \\x24admin = FullAutoAPI->model('DB::User')->search({ username => 'admin' })
+my \\x24admin = FullAutoAPI->model('DB::Users')->search({ username => 'admin' })
     ->single;
  
 \\x24admin->update({ password => 'admin', password_expires => DateTime->now });
@@ -1531,7 +1500,7 @@ END
    $ad='%NL%sub base : Chained(%SQ%/login/required%SQ%) PathPrefix '.
        'CaptureArgs(0) {}%NL%';
    ($stdout,$stderr)=$handle->cmd(
-      "${sudo}sed -i \'/index :Private/a$ad\' ./Root.pm");
+      "${sudo}sed -i \'/index : Private/i$ad\' ./Root.pm");
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i 's#default :Path#default : Chained(%SQ%/base%SQ%) ".
       "PathPart(%SQ%%SQ%) Args#' ./Root.pm");
@@ -2101,7 +2070,7 @@ END
 
 our $select_fullautoapi_setup=sub {
 
-   my @options=('FullAuto© Automation API on 1 Server');
+   my @options=('FullAuto Automation API on 1 Server');
    my $fullautoapi_setup_banner=<<'END';
 
                      _    ___     _ _   _       _                     
